@@ -1,4 +1,5 @@
 from errno import EEXIST, EISDIR, ENOENT, ENOTDIR
+import itertools
 import os
 import posixpath
 try:
@@ -26,14 +27,14 @@ class DatabaseStorage(Storage):
         try:
             return File.objects.open(name=name, mode=mode)
         except File.DoesNotExist:
-            raise IOError(ENOENT, os.strerror(ENOENT))
+            raise OSError(ENOENT, os.strerror(ENOENT))
 
     def _save(self, name, content):
         name = self._name(name)
         if name.endswith(posixpath.sep):
-            raise IOError(EISDIR, os.strerror(EISDIR))
+            raise OSError(EISDIR, os.strerror(EISDIR))
         if not name:
-            raise IOError(ENOENT, os.strerror(ENOENT))
+            raise OSError(ENOENT, os.strerror(ENOENT))
         # Extract the data from content
         data = content.read()
         # Save to the database.
@@ -43,7 +44,7 @@ class DatabaseStorage(Storage):
             except IntegrityError:
                 # File exists. We need a new file name.
                 if not self.uniquify_names:
-                    raise IOError(EEXIST, os.strerror(EEXIST))
+                    raise OSError(EEXIST, os.strerror(EEXIST))
                 name = self.get_available_name(name)
             else:
                 # OK, the file save worked. Break out of the loop.
@@ -58,13 +59,14 @@ class DatabaseStorage(Storage):
         name = self._name(name)
         dir_name, file_name = posixpath.split(name)
         file_root, file_ext = os.path.splitext(file_name)
-        # If the filename already exists, keep adding an underscore (before the
-        # file extension, if one exists) to the filename until the generated
+        # If the filename already exists, add an underscore and a number (before
+        # the file extension, if one exists) to the filename until the generated
         # filename doesn't exist.
+        count = itertools.count(1)
         while self.exists(name):
-            file_root += '_'
             # file_ext includes the dot.
-            name = posixpath.join(dir_name, file_root + file_ext)
+            name = os.path.join(dir_name, "%s_%s%s" %
+                                (file_root, count.next(), file_ext))
         return name
 
     def delete(self, name):
