@@ -208,7 +208,7 @@ class DatabaseStorageTestCase(TestCase):
     def test_open(self):
         content = StringIO('Hello world!')
         s = DatabaseStorage()
-        self.assertRaises(IOError, s.open, name='hello.txt')
+        self.assertRaises(OSError, s.open, name='hello.txt')
         s.save(name='hello.txt', content=content)
         f = s.open(name='hello.txt')
         self.assertEqual(f.read(), content.getvalue())
@@ -220,26 +220,26 @@ class DatabaseStorageTestCase(TestCase):
     def test_save(self):
         content = StringIO('Hello world!')
         s = DatabaseStorage()
-        self.assertRaises(IOError, s.save, name='', content=content)
-        self.assertRaises(IOError, s.save, name='/', content=content)
-        self.assertRaises(IOError, s.save, name='hello/', content=content)
+        self.assertRaises(OSError, s.save, name='', content=content)
+        self.assertRaises(OSError, s.save, name='/', content=content)
+        self.assertRaises(OSError, s.save, name='hello/', content=content)
         self.assertEqual(s.save(name='hello.txt', content=content),
                          'hello.txt')
         self.assertEqual(s.save(name='hello.txt', content=content),
-                         'hello_.txt')
+                         'hello_1.txt')
         self.assertEqual(s.save(name='/hello.txt', content=content),
-                         'hello__.txt')
+                         'hello_2.txt')
         # Do not allow the storage layer to retry, if not unique.
         self.assertEqual(s._save(name='hello.txt', content=content),
-                         'hello___.txt')
+                         'hello_3.txt')
         self.assertEqual(s.save(name='/hello/goodbye.txt', content=content),
                          'hello/goodbye.txt')
         # Try to save hello.txt, but without uniquify_names
         s = DatabaseStorage(uniquify_names=False)
-        self.assertRaises(IOError, s._save, name='hello.txt', content=content)
+        self.assertRaises(OSError, s._save, name='hello.txt', content=content)
         try:
             s._save(name='hello.txt', content=content)
-        except IOError, e:
+        except OSError, e:
             self.assertEqual(e.errno, errno.EEXIST)
 
     def test_get_available_name(self):
@@ -247,7 +247,7 @@ class DatabaseStorageTestCase(TestCase):
         s = DatabaseStorage()
         self.assertEqual(s.get_available_name('hello.txt'), 'hello.txt')
         s.save(name='hello.txt', content=content)
-        self.assertEqual(s.get_available_name('hello.txt'), 'hello_.txt')
+        self.assertEqual(s.get_available_name('hello.txt'), 'hello_1.txt')
 
     def test_delete(self):
         content = StringIO('Hello world!')
@@ -326,7 +326,7 @@ class DatabaseStorageTestCase(TestCase):
     def test_size(self):
         content = StringIO('Hello world!')
         s = DatabaseStorage()
-        self.assertRaises(IOError, s.size, name='hello.txt')
+        self.assertRaises(OSError, s.size, name='hello.txt')
         s.save(name='hello.txt', content=content)
         self.assertEqual(s.size(name='hello.txt'), len(content.getvalue()))
 
@@ -366,10 +366,10 @@ class NonUniquifyingDatabaseStorageTestCase(TestCase):
         s = NonUniquifyingDatabaseStorage()
         self.assertEqual(s._save(name='hello.txt', content=content),
                          'hello.txt')
-        self.assertRaises(IOError, s._save, name='hello.txt', content=content)
+        self.assertRaises(OSError, s._save, name='hello.txt', content=content)
         try:
             s._save(name='hello.txt', content=content)
-        except IOError, e:
+        except OSError, e:
             self.assertEqual(e.errno, errno.EEXIST)
 
 
